# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).

## [0.0.4] - 2022-03-16

### Fix

- fix logging level bug in LoggingLogger.

## [0.0.3] - 2021-10-13

### Removed

- remove `ModelCheckpoint` fron callcacks.

## [0.0.2] - 2021-09-02

### Added

- add `add_options` and `apply_options` in `pl_extension.utilities.config`.
- add `update_config` in `pl_extension.utilities.config`.
